# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['favicons', 'favicons._types']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.1,<8.0', 'pillow>=7.2,<8.0', 'rich>=3.3.2,<4.0.0']

setup_kwargs = {
    'name': 'favicons',
    'version': '0.0.2',
    'description': 'Favicon generator for Python',
    'long_description': '<div align="center">\n  <h1>Favicons</h1>\n  <h3>Favicon generator for Python 3 with sync & async APIs, CLI, & HTML generation.</h3>\n</div>\n\n<hr/>\n\n<div align="center">\n\n[![PyPI](https://img.shields.io/pypi/v/favicons?style=for-the-badge)](https://pypi.org/project/favicons/)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/favicons?style=for-the-badge)\n[![CI](https://img.shields.io/travis/com/checktheroads/favicons?style=for-the-badge)](https://travis-ci.com/github/checktheroads/favicons)\n\n[![GitHub Contributors](https://img.shields.io/github/contributors/checktheroads/favicons?style=for-the-badge&color=blueviolet)](https://github.com/checktheroads/favicons)\n\n\n<br/>\n\n⚠️ *This library is brand new, and is still in progress. I would strongly suggest not using it in production until this message disappears.*\n\n### [Changelog](https://github.com/checktheroads/favicons/blob/master/CHANGELOG.md)\n\n</div>\n\n- [Installation](#installation)\n- [Documentation](#documentation)\n  - [CLI](#cli)\n  - [Python Sync API](#python-sync-api)\n  - [Python Async API](#python-async-api)\n  - [HTML](#html)\n  - [Tuple](#tuple)\n  - [JSON](#json)\n- [License](#license)\n\n## Installation\n\n```shell\npip3 install favicons\n```\n\n## Documentation\n\n*More docs are coming. Remember, this is a work in progress.*\n\n\n### CLI\n\n*Coming soon*\n\n### Python Sync API\n\n```python\nfrom favicons import Favicons\n\nYOUR_ICON = "/home/user/icon.jpg"\nWEB_SERVER_ROOT = "/var/www/html"\n\nwith Favicons(YOUR_ICON, WEB_SERVER_ROOT) as favicons:\n    favicons.generate()\n    for icon in favicons.filenames():\n        print(icon)\n\n# favicon.ico\n# favicon-16x16.png\n# favicon-32x32.png\n# favicon-64x64.png\n# favicon-96x96.png\n# favicon-180x180.png\n# apple-touch-icon-57x57.png\n# apple-touch-icon-60x60.png\n# apple-touch-icon-72x72.png\n# apple-touch-icon-76x76.png\n# apple-touch-icon-114x114.png\n# apple-touch-icon-120x120.png\n# apple-touch-icon-144x144.png\n# apple-touch-icon-152x152.png\n# apple-touch-icon-167x167.png\n# apple-touch-icon-180x180.png\n# mstile-70x70.png\n# mstile-270x270.png\n# mstile-310x310.png\n# mstile-310x150.png\n# favicon-196x196.png\n```\n\n### Python Async API\n\n```python\nfrom favicons import Favicons\n\nYOUR_ICON = "/home/user/icon.jpg"\nWEB_SERVER_ROOT = "/var/www/html"\n\nasync with Favicons(YOUR_ICON, WEB_SERVER_ROOT) as favicons:\n    await favicons.generate()\n    for icon in favicons.filenames():\n        print(icon)\n\n# favicon.ico\n# favicon-16x16.png\n# favicon-32x32.png\n# favicon-64x64.png\n# favicon-96x96.png\n# favicon-180x180.png\n# apple-touch-icon-57x57.png\n# apple-touch-icon-60x60.png\n# apple-touch-icon-72x72.png\n# apple-touch-icon-76x76.png\n# apple-touch-icon-114x114.png\n# apple-touch-icon-120x120.png\n# apple-touch-icon-144x144.png\n# apple-touch-icon-152x152.png\n# apple-touch-icon-167x167.png\n# apple-touch-icon-180x180.png\n# mstile-70x70.png\n# mstile-270x270.png\n# mstile-310x310.png\n# mstile-310x150.png\n# favicon-196x196.png\n```\n\n### HTML\nGet HTML elements for each generated favicon:\n\n```python\nfrom favicons import Favicons\n\nYOUR_ICON = "/home/user/icon.jpg"\nWEB_SERVER_ROOT = "/var/www/html"\n\nasync with Favicons(YOUR_ICON, WEB_SERVER_ROOT) as favicons:\n    await favicons.generate()\n    # As generator\n    html = favicons.html_gen()\n    # As tuple\n    html = favicons.html()\n\nprint(html)\n# (\n#   \'<link rel="None" type="image/ico" href="/favicon.ico" />\',\n#   \'<link rel="icon" type="image/png" href="/favicon-16x16.png" />\',\n#   \'<link rel="icon" type="image/png" href="/favicon-32x32.png" />\',\n#   \'<link rel="icon" type="image/png" href="/favicon-64x64.png" />\',\n#   \'<link rel="icon" type="image/png" href="/favicon-96x96.png" />\',\n#   \'<link rel="icon" type="image/png" href="/favicon-180x180.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-57x57.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-60x60.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-72x72.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-76x76.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-114x114.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-120x120.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-144x144.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-152x152.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-167x167.png" />\',\n#   \'<link rel="apple-touch-icon" type="image/png" \'\n#   \'href="/apple-touch-icon-180x180.png" />\',\n#   \'<link rel="None" type="image/png" href="/mstile-70x70.png" />\',\n#   \'<link rel="None" type="image/png" href="/mstile-270x270.png" />\',\n#   \'<link rel="None" type="image/png" href="/mstile-310x310.png" />\',\n#   \'<link rel="None" type="image/png" href="/mstile-310x150.png" />\',\n#   \'<link rel="shortcut icon" type="image/png" href="/favicon-196x196.png" />\'\n# )\n```\n\n### Tuple\nGet a Python tuple containing each generated favicon\'s properties:\n\n```python\nfrom favicons import Favicons\n\nYOUR_ICON = "/home/user/icon.jpg"\nWEB_SERVER_ROOT = "/var/www/html"\n\nasync with Favicons(YOUR_ICON, WEB_SERVER_ROOT) as favicons:\n    await favicons.generate()\n    as_tuple = favicons.formats()\n    print(as_tuple)\n# (\n#   {\n#     \'dimensions\': (64, 64),\n#     \'image_format\': \'ico\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': None\n#   },\n#   {\n#     \'dimensions\': (16, 16),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'icon\'\n#   },\n#   {\n#     \'dimensions\': (32, 32),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'icon\'\n#   },\n#   {\n#     \'dimensions\': (64, 64),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'icon\'\n#   },\n#   {\n#     \'dimensions\': (96, 96),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'icon\'\n#   },\n#   {\n#     \'dimensions\': (180, 180),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'icon\'\n#   },\n#   {\n#     \'dimensions\': (57, 57),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (60, 60),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (72, 72),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (76, 76),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (114, 114),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (120, 120),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (144, 144),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (152, 152),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (167, 167),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (180, 180),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'apple-touch-icon\',\n#     \'rel\': \'apple-touch-icon\'\n#   },\n#   {\n#     \'dimensions\': (70, 70),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'mstile\',\n#     \'rel\': None\n#   },\n#   {\n#     \'dimensions\': (270, 270),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'mstile\',\n#     \'rel\': None\n#   },\n#   {\n#     \'dimensions\': (310, 310),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'mstile\',\n#     \'rel\': None\n#   },\n#   {\n#     \'dimensions\': (310, 150),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'mstile\',\n#     \'rel\': None\n#   },\n#   {\n#     \'dimensions\': (196, 196),\n#     \'image_format\': \'png\',\n#     \'prefix\': \'favicon\',\n#     \'rel\': \'shortcut icon\'\n#   }\n# )\n```\n\n### JSON\nGet a JSON array containing each generated favicon\'s properties:\n\n```python\nfrom favicons import Favicons\n\nYOUR_ICON = "/home/user/icon.jpg"\nWEB_SERVER_ROOT = "/var/www/html"\n\nasync with Favicons(YOUR_ICON, WEB_SERVER_ROOT) as favicons:\n    await favicons.generate()\n    as_json = favicons.json(indent=2)\n    print(as_json)\n\n# [\n#   {\n#     "image_format": "ico",\n#     "dimensions": [\n#       64,\n#       64\n#     ],\n#     "prefix": "favicon",\n#     "rel": null\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       16,\n#       16\n#     ],\n#     "prefix": "favicon",\n#     "rel": "icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       32,\n#       32\n#     ],\n#     "prefix": "favicon",\n#     "rel": "icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       64,\n#       64\n#     ],\n#     "prefix": "favicon",\n#     "rel": "icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       96,\n#       96\n#     ],\n#     "prefix": "favicon",\n#     "rel": "icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       180,\n#       180\n#     ],\n#     "prefix": "favicon",\n#     "rel": "icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       57,\n#       57\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       60,\n#       60\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       72,\n#       72\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       76,\n#       76\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       114,\n#       114\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       120,\n#       120\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       144,\n#       144\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       152,\n#       152\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       167,\n#       167\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       180,\n#       180\n#     ],\n#     "prefix": "apple-touch-icon",\n#     "rel": "apple-touch-icon"\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       70,\n#       70\n#     ],\n#     "prefix": "mstile",\n#     "rel": null\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       270,\n#       270\n#     ],\n#     "prefix": "mstile",\n#     "rel": null\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       310,\n#       310\n#     ],\n#     "prefix": "mstile",\n#     "rel": null\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       310,\n#       150\n#     ],\n#     "prefix": "mstile",\n#     "rel": null\n#   },\n#   {\n#     "image_format": "png",\n#     "dimensions": [\n#       196,\n#       196\n#     ],\n#     "prefix": "favicon",\n#     "rel": "shortcut icon"\n#   }\n# ]\n```\n\n## License\n\n[Clear BSD License](https://github.com/checktheroads/blob/favicons/master/LICENSE)\n',
    'author': 'checktheroads',
    'author_email': 'matt@allroads.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/checktheroads/favicons',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
